@@ -1,21 +1,34 @@
 /*
-    SPDX-FileCopyrightText: 2009 Grégory Oestreicher <greg@kamago.net>
+    Copyright (c) 2009 Grégory Oestreicher <greg@kamago.net>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#include "groupdavprotocol_p.h"
+#include "groupdavprotocol.h"
 
-#include "common/utils_p.h"
+#include "common/utils.h"
 
-#include <QDomDocument>
+#include <QtCore/QVariant>
+#include <QtXml/QDomDocument>
 
 using namespace KDAV;
 
 class GroupdavCollectionQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
 
@@ -31,7 +44,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QString();
     }
@@ -40,7 +53,7 @@ public:
 class GroupdavItemQueryBuilder : public XMLQueryBuilder
 {
 public:
-    QDomDocument buildQuery() const override
+    QDomDocument buildQuery() const Q_DECL_OVERRIDE
     {
         QDomDocument document;
 
@@ -57,7 +70,7 @@ public:
         return document;
     }
 
-    QString mimeType() const override
+    QString mimeType() const Q_DECL_OVERRIDE
     {
         return QString();
     }
@@ -87,16 +100,16 @@ XMLQueryBuilder::Ptr GroupdavProtocol::collectionsQuery() const
     return XMLQueryBuilder::Ptr(new GroupdavCollectionQueryBuilder());
 }
 
-bool GroupdavProtocol::containsCollection(const QDomElement &propElem) const
+QString GroupdavProtocol::collectionsXQuery() const
 {
-    return !propElem.elementsByTagNameNS(QStringLiteral("http://groupdav.org/"), QStringLiteral("vevent-collection")).isEmpty()
-        || !propElem.elementsByTagNameNS(QStringLiteral("http://groupdav.org/"), QStringLiteral("vtodo-collection")).isEmpty()
-        || !propElem.elementsByTagNameNS(QStringLiteral("http://groupdav.org/"), QStringLiteral("vcard-collection")).isEmpty();
+    const QString query(QStringLiteral("//*[(local-name()='vevent-collection' or local-name()='vtodo-collection' or local-name()='vcard-collection') and namespace-uri()='http://groupdav.org/']/ancestor::*[local-name()='response' and namespace-uri()='DAV:']"));
+
+    return query;
 }
 
-QList<XMLQueryBuilder::Ptr> GroupdavProtocol::itemsQueries() const
+QVector<XMLQueryBuilder::Ptr> GroupdavProtocol::itemsQueries() const
 {
-    QList<XMLQueryBuilder::Ptr> ret;
+    QVector<XMLQueryBuilder::Ptr> ret;
     ret << XMLQueryBuilder::Ptr(new GroupdavItemQueryBuilder());
     return ret;
 }
